@@ -8,7 +8,10 @@ from importlib import import_module
 
 from distutils.errors import DistutilsOptionError, DistutilsFileError
 from packaging.version import LegacyVersion, parse
-from six import string_types
+from six import string_types, PY3
+
+
+__metaclass__ = type
 
 
 def read_configuration(
@@ -113,7 +116,7 @@ def parse_configuration(
     return meta, options
 
 
-class ConfigHandler(object):
+class ConfigHandler:
     """Handles metadata supplied in configuration files."""
 
     section_prefix = None
@@ -512,16 +515,24 @@ class ConfigOptionsHandler(ConfigHandler):
         :param value:
         :rtype: list
         """
-        find_directive = 'find:'
+        find_directives = ['find:', 'find_namespace:']
+        trimmed_value = value.strip()
 
-        if not value.startswith(find_directive):
+        if not trimmed_value in find_directives:
             return self._parse_list(value)
 
+        findns = trimmed_value == find_directives[1]
+        if findns and not PY3:
+            raise DistutilsOptionError('find_namespace: directive is unsupported on Python < 3.3')
+
         # Read function arguments from a dedicated section.
         find_kwargs = self.parse_section_packages__find(
             self.sections.get('packages.find', {}))
 
-        from setuptools import find_packages
+        if findns:
+            from setuptools import find_namespace_packages as find_packages
+        else:
+            from setuptools import find_packages
 
         return find_packages(**find_kwargs)
 
@@ -587,3 +598,11 @@ class ConfigOptionsHandler(ConfigHandler):
         parse_list = partial(self._parse_list, separator=';')
         self['extras_require'] = self._parse_section_to_dict(
             section_options, parse_list)
+
+    def parse_section_data_files(self, section_options):
+        """Parses `data_files` configuration file section.
+
+        :param dict section_options:
+        """
+        parsed = self._parse_section_to_dict(section_options, self._parse_list)
+        self['data_files'] = [(k, v) for k, v in parsed.items()]
